==> nextcloud-app-spreed-1:17.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/spreed/l10n/es_CR.js <==
OC.L10N.register(
    "spreed",
    {
    "(Duration %s)" : "(Duración %s)",
    "You attended a call with {user1}" : "Tomaste una llamda con {user1}",
    "_%n guest_::_%n guests_" : ["%n inivitado","%n inivitados","%n inivitados"],
    "You attended a call with {user1} and {user2}" : "Tuviste una llamada con {user1} y {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Tuviste una llamada con {user1}, {user2} y {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Tuviste una llamada con {user1}, {user2}, {user3} y {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Tuviste una llamada con {user1}, {user2}, {user3}, {user4} y {user5}",
    "_%n other_::_%n others_" : ["%n otro","otros %n","otros %n"],
    "{actor} invited you to {call}" : "{actor} te ha invitado a {call}",
    "Talk" : "Hablar",
    "Guest" : "Invitado",
    "Talk to %s" : "Hablar con %s",
    "File is too big" : "El archivo es demasiado grande.",
    "Invalid file provided" : "Archivo proporcionado inválido",
    "Invalid image" : "Imagen inválida",
    "Unknown filetype" : "Tipo de archivo desconocido",
    "Join call" : "Unirse a la llamada",
    "A group call has started in {call}" : "Una llamada en grupo ha iniciado en {call}",
    "Open settings" : "Abrir configuraciones",
    "Conversations" : "Conversaciones",
    "Avatar image is not square" : "La imagen del avatar no es un cuadrado",
    "Invalid date, date format must be YYYY-MM-DD" : "La fecha es inválida, por favor sigue el formato AAAA-MM-DD",
    "Leave call" : "Dejar la llamada",
    "This conversation has ended" : "Esta conversación ha terminado",
    "Limit to groups" : "Limitar a grupos",
    "Everyone" : "Todos",
    "Save changes" : "Guardar cambios",
    "Saved!" : "¡Guardado!",
    "Name" : "Nombre",
    "None" : "Ninguno",
    "User" : "Usuario",
    "Disabled" : "Deshabilitado",
    "Users" : "Usuarios",
    "General settings" : "Configuraciones generales",
    "Language" : "Idioma",
    "Country" : "País",
    "Status" : "Estatus",
    "Created at" : "Creado en",
    "Pending" : "Pendiente",
    "Error" : "Error",
    "Blocked" : "Bloqueado",
    "Expired" : "Expirado",
    "Validate SSL certificate" : "Validar certificado SSL",
    "Shared secret" : "Secreto compartido",
    "STUN servers" : "Servidores STUN",
    "A STUN server is used to determine the public IP address of participants behind a router." : "Un servidor STUN se está usando para determinar la IP pública de los participantes que estén detrás de un ruteador. ",
    "TURN server protocols" : "Protocolos del servidor TURN",
    "OK" : "OK",
    "Checking …" : "Verificando ...",
    "Back" : "Atrás",
    "Confirm" : "Confirmar",
    "Reset" : "Restablecer",
    "Cancel" : "Cancelar",
    "Copy link" : "Copiar liga",
    "Waiting for others to join the call …" : "Esperando a que los demás se unan a la llamada ...",
    "You can invite others in the participant tab of the sidebar" : "Puedes invitar a otras personas en la pestaña de participante del menú lateral",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "¡Puedes invitar a otros usando la pestaña de participante de la barra lateral o compartiendo esta liga para invitar a otras personas!",
    "Share this link to invite others!" : "¡Comparte esta liga para invitar a otras personas!",
    "Mute audio" : "Silenciar audio",
    "Disable video" : "Deshabilitar video",
    "Enable video" : "Habilitar el video",
    "You" : "Tú",
    "Show screen" : "Mostrar pantalla",
    "Collapse" : "Colapsar",
    "Favorite" : "Hacer favorito",
    "Description" : "Descripción",
    "Restricted" : "Restringido",
    "Personal" : "Personal",
    "Permissions" : "Permisos",
    "Leave conversation" : "Dejar la conversación",
    "Delete conversation" : "Borrar conversación",
    "Submit" : "Enviar",
    "Password protection" : "Protección con contraseña",
    "Save" : "Guardar",
    "Edit" : "Editar",
    "Delete" : "Borrar",
    "Password" : "Contraseña",
    "API token" : "Ficha del API",
    "Login" : "Iniciar sesión",
    "Nickname" : "Apodo",
    "Client ID" : "ID del cliente",
    "Notifications" : "Notificaciones",
    "Remove from favorites" : "Eliminar de favoritos",
    "Add to favorites" : "Agregar a tus favoritos",
    "Loading" : "Cargando",
    "Groups" : "Grupos",
    "Circles" : "Círculos",
    "Password protect" : "Proteger con contraseña",
    "Close" : "Cerrar",
    "Conversation name" : "Nombre de la conversación",
    "Devices" : "Dispositivos",
    "No audio" : "Sin audio",
    "Upload" : "Cargar",
    "Files" : "Archivos",
    "Dismiss" : "Descartar",
    "Reply" : "Responder",
    "Translate" : "Traducir",
    "Contact" : "Contacto",
    "Today" : "Hoy",
    "Yesterday" : "Ayer",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "Group" : "Grupo",
    "Create new poll" : "Crear nueva encuesta",
    "Settings" : "Configuraciones ",
    "Create poll" : "Crear encuesta",
    "Send" : "Enviar",
    "moderator" : "moderador",
    "Demote from moderator" : "Degradar de moderador",
    "Promote to moderator" : "Promover a moderador",
    "Remove participant" : "Eliminar participante",
    "No results" : "No hay resultados",
    "Add users or groups" : "Agregar usuarios o grupos",
    "Participants" : "Participantes",
    "Chat" : "Chat",
    "Details" : "Detalles",
    "Privacy" : "Privacidad",
    "Keyboard shortcuts" : "Atajos del teclado",
    "Search" : "Buscar",
    "Show your screen" : "Mostrar tu pantalla",
    "Stop screensharing" : "Dejar de compartir la pantalla",
    "Screensharing options" : "Opciones de compartir pantalla",
    "Enable screensharing" : "Habilitar compartir pantalla",
    "Screensharing requires the page to be loaded through HTTPS." : "Compartir pantalla requiere que la página se cargue a través de HTTPS.",
    "Sharing your screen only works with Firefox version 52 or newer." : "Compartir la pantalla sólo funciona con Firefox versión 52 o superior. ",
    "Screensharing extension is required to share your screen." : "Se requiere de la extenisón de compartir pantalla para compartir tu pantalla. ",
    "Please use a different browser like Firefox or Chrome to share your screen." : "Por favor usa un navegador diferente como Firefox o Chrome para compartir tu pantalla.",
    "An error occurred while starting screensharing." : "Se presentó un error al comenzar a compartir la pantalla. ",
    "Grid view" : "Vista de cuadrícula",
    "Join a conversation or start a new one" : "Únete a la conversación o incia una nueva",
    "Polls" : "Encuestas",
    "Audio" : "Audio",
    "Other" : "Otro",
    "Default" : "Predeterminado",
    "Access to microphone & camera is only possible with HTTPS" : "El acceso al micrófono & cámara sólo es posible mediante HTTPS",
    "Please move your setup to HTTPS" : "Por favor cambia tu configuración a HTTPS",
    "Access to microphone & camera was denied" : "El acceso al micrófono & cámara fue denegado",
    "WebRTC is not supported in your browser" : "WebRTC no está soportado en tu navegador",
    "Please use a different browser like Firefox or Chrome" : "Por favor usa un navegador diferente como Firefox o Chrome",
    "Error while accessing microphone & camera" : "Se pressentó un error al acceder al micrófono & cámara",
    "The password is wrong. Try again." : "La contraseña está equivoada. Por favor vuelve a intentarlo. ",
    "TURN server" : "Servidor TURN",
    "The TURN server is used to proxy the traffic from participants behind a firewall." : "El servidor TURN se usa para concentrar el tráfico de participantes detras de un firewall. ",
    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "Un servidor externo de señalización puede ser, opcionalmente, utilizado para instalaciones más grandes. Déjalo vacío para usar el sevidor de señalización interno. ",
    "Android app" : "Aplicación Android",
    "iOS app" : "Aplicación iOS",
    "More actions" : "Más acciones",
    "Rename conversation" : "Renombrar conversación"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-app-spreed-1:20.1.0-1.0-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/spreed/l10n/es_CR.js <==
OC.L10N.register(
    "spreed",
    {
    "(Duration %s)" : "(Duración %s)",
    "You attended a call with {user1}" : "Tomaste una llamda con {user1}",
    "_%n guest_::_%n guests_" : ["%n inivitado","%n inivitados","%n inivitados"],
    "You attended a call with {user1} and {user2}" : "Tuviste una llamada con {user1} y {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Tuviste una llamada con {user1}, {user2} y {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Tuviste una llamada con {user1}, {user2}, {user3} y {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Tuviste una llamada con {user1}, {user2}, {user3}, {user4} y {user5}",
    "_%n other_::_%n others_" : ["%n otro","otros %n","otros %n"],
    "{actor} invited you to {call}" : "{actor} te ha invitado a {call}",
    "Talk" : "Hablar",
    "Guest" : "Invitado",
    "Talk to %s" : "Hablar con %s",
    "File is too big" : "El archivo es demasiado grande.",
    "Invalid file provided" : "Archivo proporcionado inválido",
    "Invalid image" : "Imagen inválida",
    "Unknown filetype" : "Tipo de archivo desconocido",
    "Accept" : "Aceptar",
    "Decline" : "Declinar",
    "Join call" : "Unirse a la llamada",
    "A group call has started in {call}" : "Una llamada en grupo ha iniciado en {call}",
    "Open settings" : "Abrir configuraciones",
    "error" : "error",
    "Conversations" : "Conversaciones",
    "Avatar image is not square" : "La imagen del avatar no es un cuadrado",
    "Federation" : "Federación",
    "Invalid date, date format must be YYYY-MM-DD" : "La fecha es inválida, por favor sigue el formato AAAA-MM-DD",
    "Leave call" : "Dejar la llamada",
    "This conversation has ended" : "Esta conversación ha terminado",
    "Limit to groups" : "Limitar a grupos",
    "Everyone" : "Todos",
    "Save changes" : "Guardar cambios",
    "Saved!" : "¡Guardado!",
    "Name" : "Nombre",
    "Description" : "Descripción",
    "Enabled" : "Habilitado",
    "Disabled" : "Deshabilitado",
    "Permissions" : "Permisos",
    "General settings" : "Configuraciones generales",
    "Language" : "Idioma",
    "Country" : "País",
    "Status" : "Estatus",
    "Created at" : "Creado en",
    "Pending" : "Pendiente",
    "Error" : "Error",
    "Blocked" : "Bloqueado",
    "Expired" : "Expirado",
    "Validate SSL certificate" : "Validar certificado SSL",
    "Shared secret" : "Secreto compartido",
    "STUN servers" : "Servidores STUN",
    "A STUN server is used to determine the public IP address of participants behind a router." : "Un servidor STUN se está usando para determinar la IP pública de los participantes que estén detrás de un ruteador. ",
    "TURN server protocols" : "Protocolos del servidor TURN",
    "OK" : "OK",
    "Checking …" : "Verificando ...",
    "Back" : "Atrás",
    "Cancel" : "Cancelar",
    "Confirm" : "Confirmar",
    "Reset" : "Restablecer",
    "Copy link" : "Copiar liga",
    "Waiting for others to join the call …" : "Esperando a que los demás se unan a la llamada ...",
    "You can invite others in the participant tab of the sidebar" : "Puedes invitar a otras personas en la pestaña de participante del menú lateral",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "¡Puedes invitar a otros usando la pestaña de participante de la barra lateral o compartiendo esta liga para invitar a otras personas!",
    "Share this link to invite others!" : "¡Comparte esta liga para invitar a otras personas!",
    "Mute audio" : "Silenciar audio",
    "Disable video" : "Deshabilitar video",
    "Enable video" : "Habilitar el video",
    "You" : "Tú",
    "Show screen" : "Mostrar pantalla",
    "Collapse" : "Colapsar",
    "Favorite" : "Hacer favorito",
    "Hide details" : "Ocultar detalles",
    "Disable" : "Deshabilitar",
    "Choose" : "Seleccionar",
    "Restricted" : "Restringido",
    "Personal" : "Personal",
    "Leave conversation" : "Dejar la conversación",
    "Delete conversation" : "Borrar conversación",
    "Password protection" : "Protección con contraseña",
    "Save" : "Guardar",
    "Edit" : "Editar",
    "Delete" : "Borrar",
    "Log content" : "Contenido de bitácoras",
    "Notifications" : "Notificaciones",
    "Login" : "Iniciar sesión",
    "Remove from favorites" : "Eliminar de favoritos",
    "Add to favorites" : "Agregar a tus favoritos",
    "Users" : "Usuarios",
    "Groups" : "Grupos",
    "Loading" : "Cargando",
    "None" : "Ninguno",
    "Devices" : "Dispositivos",
    "No audio" : "Sin audio",
    "Upload" : "Cargar",
    "Files" : "Archivos",
    "Reply" : "Responder",
    "Translate" : "Traducir",
    "Dismiss" : "Descartar",
    "Contact" : "Contacto",
    "Today" : "Hoy",
    "Yesterday" : "Ayer",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "_%n day ago_::_%n days ago_" : ["hace %n día","hace %n días","hace %n días"],
    "Close" : "Cerrar",
    "Password protect" : "Proteger con contraseña",
    "Create new poll" : "Crear nueva encuesta",
    "Settings" : "Configuraciones ",
    "Create poll" : "Crear encuesta",
    "Send" : "Enviar",
    "moderator" : "moderador",
    "Demote from moderator" : "Degradar de moderador",
    "Promote to moderator" : "Promover a moderador",
    "Remove participant" : "Eliminar participante",
    "No results" : "No hay resultados",
    "Add users or groups" : "Agregar usuarios o grupos",
    "Participants" : "Participantes",
    "Chat" : "Chat",
    "Details" : "Detalles",
    "Privacy" : "Privacidad",
    "Keyboard shortcuts" : "Atajos del teclado",
    "Search" : "Buscar",
    "Show your screen" : "Mostrar tu pantalla",
    "Stop screensharing" : "Dejar de compartir la pantalla",
    "Screensharing options" : "Opciones de compartir pantalla",
    "Enable screensharing" : "Habilitar compartir pantalla",
    "Screensharing requires the page to be loaded through HTTPS." : "Compartir pantalla requiere que la página se cargue a través de HTTPS.",
    "Sharing your screen only works with Firefox version 52 or newer." : "Compartir la pantalla sólo funciona con Firefox versión 52 o superior. ",
    "Screensharing extension is required to share your screen." : "Se requiere de la extenisón de compartir pantalla para compartir tu pantalla. ",
    "Please use a different browser like Firefox or Chrome to share your screen." : "Por favor usa un navegador diferente como Firefox o Chrome para compartir tu pantalla.",
    "An error occurred while starting screensharing." : "Se presentó un error al comenzar a compartir la pantalla. ",
    "Grid view" : "Vista de cuadrícula",
    "Submit" : "Enviar",
    "Join a conversation or start a new one" : "Únete a la conversación o incia una nueva",
    "User" : "Usuario",
    "Password" : "Contraseña",
    "API token" : "Ficha del API",
    "Nickname" : "Apodo",
    "Client ID" : "ID del cliente",
    "Polls" : "Encuestas",
    "Audio" : "Audio",
    "Other" : "Otro",
    "Group" : "Grupo",
    "Default" : "Predeterminado",
    "Access to microphone & camera is only possible with HTTPS" : "El acceso al micrófono & cámara sólo es posible mediante HTTPS",
    "Please move your setup to HTTPS" : "Por favor cambia tu configuración a HTTPS",
    "Access to microphone & camera was denied" : "El acceso al micrófono & cámara fue denegado",
    "WebRTC is not supported in your browser" : "WebRTC no está soportado en tu navegador",
    "Please use a different browser like Firefox or Chrome" : "Por favor usa un navegador diferente como Firefox o Chrome",
    "Error while accessing microphone & camera" : "Se pressentó un error al acceder al micrófono & cámara",
    "The password is wrong. Try again." : "La contraseña está equivoada. Por favor vuelve a intentarlo. ",
    "Android app" : "Aplicación Android",
    "iOS app" : "Aplicación iOS",
    "Circles" : "Círculos",
    "TURN server" : "Servidor TURN",
    "The TURN server is used to proxy the traffic from participants behind a firewall." : "El servidor TURN se usa para concentrar el tráfico de participantes detras de un firewall. ",
    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "Un servidor externo de señalización puede ser, opcionalmente, utilizado para instalaciones más grandes. Déjalo vacío para usar el sevidor de señalización interno. "
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
